;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                                                     ;;;
;;;                     Carnegie Mellon University                      ;;;
;;;                  and Alan W Black and Kevin Lenzo                   ;;;
;;;                      Copyright (c) 1998-2000                        ;;;
;;;                        All Rights Reserved.                         ;;;
;;;                                                                     ;;;
;;; Permission is hereby granted, free of charge, to use and distribute ;;;
;;; this software and its documentation without restriction, including  ;;;
;;; without limitation the rights to use, copy, modify, merge, publish, ;;;
;;; distribute, sublicense, and/or sell copies of this work, and to     ;;;
;;; permit persons to whom this work is furnished to do so, subject to  ;;;
;;; the following conditions:                                           ;;;
;;;  1. The code must retain the above copyright notice, this list of   ;;;
;;;     conditions and the following disclaimer.                        ;;;
;;;  2. Any modifications must be clearly marked as such.               ;;;
;;;  3. Original authors' names are not deleted.                        ;;;
;;;  4. The authors' names are not used to endorse or promote products  ;;;
;;;     derived from this software without specific prior written       ;;;
;;;     permission.                                                     ;;;
;;;                                                                     ;;;
;;; CARNEGIE MELLON UNIVERSITY AND THE CONTRIBUTORS TO THIS WORK        ;;;
;;; DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING     ;;;
;;; ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT  ;;;
;;; SHALL CARNEGIE MELLON UNIVERSITY NOR THE CONTRIBUTORS BE LIABLE     ;;;
;;; FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES   ;;;
;;; WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN  ;;;
;;; AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,         ;;;
;;; ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF      ;;;
;;; THIS SOFTWARE.                                                      ;;;
;;;                                                                     ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Phonset for net_dutch
;;;

;;;  Feel free to add new feature values, or new features to this
;;;  list to make it more appropriate to your language

(defPhoneSet
  net_dutch
  ;;;  Phone Features
  (;; vowel or consonant
   (vc + - 0)  
   ;; vowel length: short or long
   (vlng s l 0)
   ;; vowel type: short long dipthong schwa
   (vtype s l d a 0)
   ;; vowel height: high mid low
   (vheight 1 2 3 0)
   ;; vowel frontness: front mid back
   (vfront 1 2 3 0)
   ;; lip rounding
   (vrnd + - 0)
   ;; consonant type: plosive fricative affricative nasal liquid
   (ctype p f a n l r 0)
   ;; place of articulation: labial alveolar palatal labio-dental
   ;;                        dental velar glottal
   (cplace l a p b d v g 0)
   ;; consonant voicing
   (cvox + - 0)
   )
  (
     (#   0   0   0   0   0   -   0   0   -) ;; silence
	 
     (ux  +   s   s   2   3   +   0   0   0) ;; nUl
	 (e:  +   l   l   2   1   -   0   0   0) ;;
     (a	  +   s   s   3   3   -   0   0   0) ;; Acht
	 (i:  +   s   s   1   1   -   0   0   0) ;; drIE
     (Ei  +   l   d   3   2   -   0   0   0) ;;
     (e   +   l   l   2   1   -   0   0   0) ;;
     (&   +   s   s   2   3   +   0   0   0) ;; negEn
   
	 (n   -   0   0   0   0   0   n   a   +) ;; Nul
     (V[  -   0   0   0   0   0   l   l   +) ;; tWee
     (t   -   0   0   0   0   0   p   a   -) ;; Twee
     (d   -   0   0   0   0   0   p   a   +) ;; Drie
     (R   -   0   0   0   0   0   r   a   +) ;; dRie
	 (l   -   0   0   0   0   0   l   a   +) ;; 
	 (s   -   0   0   0   0   0   f   a   -) ;; zeS
     (x   -   0   0   0   0   0   f   g   -) ;; aCHt
	 (G   -   0   0   0   0   0   f   g   +) ;; neGen
     (f   -   0   0   0   0   0   f   b   -) ;; vijF
     (v   -   0   0   0   0   0   f   b   +) ;; Vijf
     (z   -   0   0   0   0   0   f   a   +) ;; Zes
  )
)

(PhoneSet.silences '(#))

(define (net_dutch_frans::select_phoneset)
  "(net_dutch_frans::select_phoneset)
Set up phone set for net_dutch."
  (Parameter.set 'PhoneSet 'net_dutch)
  (PhoneSet.select 'net_dutch)
)

(define (net_dutch_frans::reset_phoneset)
  "(net_dutch_frans::reset_phoneset)
Reset phone set for net_dutch."
  t
)

(provide 'net_dutch_frans_phoneset)
